@@ -28,6 +28,7 @@ def main():
 	parser = OptionParser("%prog [options] file")
 	parser.add_option('-u', '--url', help='load url (instead of file)')
 	parser.add_option('-v', '--verbose', action='store_true', help='verbose messaging')
+	parser.add_option('-g', '--graph', action='store_true', help='pretty graphs (NOTE: requires pyx)')
 	opts, args = parser.parse_args()
 	if opts.verbose:
 		misc.set_debug(True)
@@ -39,7 +40,10 @@ def main():
 	else:
 		doc = from_file(args[0])
 	print doc
-
+	
+	if opts.graph:
+		from graph import graph
+		graph(doc.stats)
 
 if __name__ == '__main__':
 	sys.exit(main())
